@@ -14,7 +14,7 @@ from emmet.builders.molecules.summary import SummaryBuilder
 
 @pytest.fixture(scope="session")
 def tasks(test_dir):
-    return JSONStore(test_dir / "C3H4Li1O3.json.gz")
+    return JSONStore(test_dir / "C2H4.json.gz")
 
 
 @pytest.fixture(scope="session")
@@ -107,4 +107,4 @@ def test_summary_doc(
     )
     builder.run()
 
-    assert summary.count() == 48
+    assert summary.count() == 11
